==> material__dialog-1.1.0.jar: META-INF/resources/webjars/material__dialog/1.1.0/constants.d.ts <==
/**
 * @license
 * Copyright 2016 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
export declare const cssClasses: {
    CLOSING: string;
    OPEN: string;
    OPENING: string;
    SCROLLABLE: string;
    SCROLL_LOCK: string;
    STACKED: string;
};
export declare const strings: {
    ACTION_ATTRIBUTE: string;
    BUTTON_SELECTOR: string;
    CLOSED_EVENT: string;
    CLOSE_ACTION: string;
    CLOSING_EVENT: string;
    CONTAINER_SELECTOR: string;
    CONTENT_SELECTOR: string;
    DEFAULT_BUTTON_SELECTOR: string;
    DESTROY_ACTION: string;
    OPENED_EVENT: string;
    OPENING_EVENT: string;
    SCRIM_SELECTOR: string;
    SUPPRESS_DEFAULT_PRESS_SELECTOR: string;
    SURFACE_SELECTOR: string;
};
export declare const numbers: {
    DIALOG_ANIMATION_CLOSE_TIME_MS: number;
    DIALOG_ANIMATION_OPEN_TIME_MS: number;
};

==> material__dialog-10.0.0.jar: META-INF/resources/webjars/material__dialog/10.0.0/constants.d.ts <==
/**
 * @license
 * Copyright 2016 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
export declare const cssClasses: {
    CLOSING: string;
    OPEN: string;
    OPENING: string;
    SCROLLABLE: string;
    SCROLL_LOCK: string;
    STACKED: string;
    FULLSCREEN: string;
    SCROLL_DIVIDER_HEADER: string;
    SCROLL_DIVIDER_FOOTER: string;
};
export declare const strings: {
    ACTION_ATTRIBUTE: string;
    BUTTON_DEFAULT_ATTRIBUTE: string;
    BUTTON_SELECTOR: string;
    CLOSED_EVENT: string;
    CLOSE_ACTION: string;
    CLOSING_EVENT: string;
    CONTAINER_SELECTOR: string;
    CONTENT_SELECTOR: string;
    DESTROY_ACTION: string;
    INITIAL_FOCUS_ATTRIBUTE: string;
    OPENED_EVENT: string;
    OPENING_EVENT: string;
    SCRIM_SELECTOR: string;
    SUPPRESS_DEFAULT_PRESS_SELECTOR: string;
    SURFACE_SELECTOR: string;
};
export declare const numbers: {
    DIALOG_ANIMATION_CLOSE_TIME_MS: number;
    DIALOG_ANIMATION_OPEN_TIME_MS: number;
};
